<?php
/**
 * Cette classe fournit une interface pour la configuration du module de notification
 * @copyright   &copy; 2005-2019 PHPBoost
 * @license     https://www.gnu.org/licenses/gpl-3.0.html GNU/GPL-3.0
 * @author      Kévin BRISSEZ <brissez.kevin@gmail.com>
 * @version     PHPBoost 5.2 - last update: 2019 11 01
 * @since       PHPBoost 5.0 - 2019 07 01
 */

class AdminNotificationsConfigController extends AdminModuleController
  {
    
    private $form;
    /**
     * @var FormButtonSubmit
     */
    private $submit_button;
    
    private $lang;
    private $admin_common_lang;
    
    /**
     * @var NotificationsConfig
     */
    private $config;
    
    public function execute(HTTPRequestCustom $request)
      {
        $this->init();
        
        $this->build_form();
        
        $tpl = new StringTemplate('# INCLUDE MSG # # INCLUDE FORM #');
        $tpl->add_lang($this->lang);
        
        if ($this->submit_button->has_been_submited() && $this->form->validate())
          {
            if ($this->form->get_value('del_notif_after_view') == TRUE AND $this->form->get_value('archivage_auto') == TRUE)
              {
                $tpl->put('MSG', MessageHelper::display(LangLoader::get_message('admin.notifications.form.arch_del.error', 'common', 'notifications'), MessageHelper::ERROR, 5));
                
              }
            else
              {
                $this->save();
                $tpl->put('MSG', MessageHelper::display(LangLoader::get_message('message.success.config', 'status-messages-common'), MessageHelper::SUCCESS, 5));
              }
          }
        
        $tpl->put('FORM', $this->form->display());
        
        return new AdminNotificationsDisplayResponse($tpl, $this->lang['module_config_title']);
      }
    
    private function init()
      {
        $this->config            = NotificationsConfig::load();
        $this->lang              = LangLoader::get('common', 'notifications');
        $this->admin_common_lang = LangLoader::get('admin-common');
      }
    
    private function build_form()
      {
        $form = new HTMLForm(__CLASS__);
        
        $fieldset = new FormFieldsetHTML('config', $this->admin_common_lang['configuration']);
        $form->add_fieldset($fieldset);
        
        $fieldset->add_field(new FormFieldNumberEditor('items_per_page', $this->admin_common_lang['config.items_number_per_page'], $this->config->get_items_per_page(), array(
            'class' => 'top-field',
            'min' => 1,
            'max' => 50,
            'required' => true
        ), array(
            new FormFieldConstraintIntegerRange(1, 50)
        )));
        $fieldset->add_field(new FormFieldCheckbox('del_notif_after_view', $this->lang['admin.notification.del_notif_after_view'], $this->config->get_del_notif_after_view(), array(
            'class' => 'top-field',
            'description' => $this->lang['admin.notification.del_notif_after_view.desc']
        )));
        
        $fieldset->add_field(new FormFieldCheckbox('archivage_auto', $this->lang['admin.notifications.archivage.auto'], $this->config->get_archivage_auto(), array(
            'class' => 'top-field',
            'description' => $this->lang['admin.notifications.archivage.auto.desc']
        )));
        
        $this->submit_button = new FormButtonDefaultSubmit();
        $form->add_button($this->submit_button);
        $form->add_button(new FormButtonReset());
        
        $this->form = $form;
      }
    
    
    
    private function save()
      {
        $this->config->set_items_per_page((int) $this->form->get_value('items_per_page'));
        $this->config->set_del_notif_after_view((bool) $this->form->get_value('del_notif_after_view'));
        $this->config->set_archivage_auto((int) $this->form->get_value('archivage_auto'));
        NotificationsConfig::save();
      }
  }
?>