<?php
/**
 * Cette classe fournit l'installation du module de notifications
 * @copyright   &copy; 2005-2019 PHPBoost
 * @license     https://www.gnu.org/licenses/gpl-3.0.html GNU/GPL-3.0
 * @author      Kévin BRISSEZ <brissez.kevin@gmail.com>
 * @version     PHPBoost 5.2 - last update: 2019 11 01
 * @since       PHPBoost 5.0 - 2019 07 01
 */

class NotificationsSetup extends DefaultModuleSetup
  {
    public static $notifications_table;
    
    public static function __static()
      {
        self::$notifications_table = PREFIX . 'notifications';
      }
    
    public function install()
      {
        $this->drop_tables();
        $this->create_tables();
      }
    
    public function uninstall()
      {
        $this->drop_tables();
        $this->delete_configuration();
      }
    
    private function drop_tables()
      {
        PersistenceContext::get_dbms_utils()->drop(array(
            self::$notifications_table
        ));
      }
    
    private function delete_configuration()
      {
        ConfigManager::delete('notifications', 'config');
      }
    
    private function create_tables()
      {
        $this->create_notifications_table();
      }
    
    private function create_notifications_table()
      {
        $fields  = array(
            'id' => array(
                'type' => 'integer',
                'length' => 11,
                'autoincrement' => true,
                'notnull' => 1
            ),
            'sender_id' => array(
                'type' => 'integer',
                'length' => 11,
                'notnull' => 1,
                'default' => 0
            ),
            'recipient_id' => array(
                'type' => 'integer',
                'length' => 11,
                'notnull' => 1,
                'default' => 0
            ),
            'content' => array(
                'type' => 'text',
                'length' => 2000
            ),
            'date' => array(
                'type' => 'integer',
                'length' => 11,
                'notnull' => 1,
                'default' => 0
            ),
            'reading' => array(
                'type' => 'integer',
                'length' => 1,
                'notnull' => 1,
                'default' => 0
            )
        );
        $options = array(
            'primary' => array(
                'id'
            )
        );
        PersistenceContext::get_dbms_utils()->create_table(self::$notifications_table, $fields, $options);
      }
  }
?>